
title 'resistance welding'
coordinates ycylinder
select
errlim=1e-4
ngrid=30
nodelimit=100
smoothinit

VARIABLES
temp(threshold=10)
U
solid(threshold=0.01)

DEFINITIONS
mm=0.001
dni=1.4*mm     Dti=3*mm     Lni=15*mm      Lti=7.5*mm
Laram=5*mm
lambda {W/mK}    c {J/kgK}     ro {kg/m3}
alfa=50

t_heg=0.114 {sec, welding time}
t_elo=0.010 {sec}

I_elo=200 * upulse(t, t-t_elo) {A}
I_heg=1200 * upulse(t-t_elo, t-t_elo-t_heg) {A, main welding current}
I=I_elo+I_heg {A, welding current}

Ati=5.5292*mm^2 {m2, cross section}

flux_r=-lambda*dr(temp)     flux_z=-lambda*dz(temp)
flux=vector(flux_r, flux_z)     fluxm=magnitude(flux)

res {resistance, ohm*m}
cond=1/res {conductivity,  = 1  /  resistance}
Er=-dr(U)     Ez=-dz(U)     E=-grad(U)    Em=magnitude(E)
Jr=cond*Er     Jz=cond*Ez     J=cond*E     Jm=magnitude(J)

Qm {J/kg, latent heat of melting}
Tm {oC, melting point}
T0 {oC, +- }
Tinit {oC, initial temperature}
sinit {initial solid}

eps=1e-10

EQUATIONS
U:     div(J)=0
temp:     div(flux)+ ro*c*dt( temp)=Jm*Em+Qm*ro*dt(solid)
solid:     solid - eps*div(grad(solid)) = 0.5*erfc(4*(temp-Tm)/T0)
initial values
temp=25
U=0
solid=0.5*erfc(4*(Tinit-Tm)/T0)

BOUNDARIES
REGION 'nitinol'
ro=6500     c=322.17     lambda=10     {res=0.82e-6} res=1e10 {fictive value -> makes current flow only in titan (used instead of high resistance of contact)}
Qm=296800     Tm=1310     T0=50 ! 1
Tinit=25     sinit=1
start (0, -Lni/4)
natural(solid)=0 natural(temp)=alfa*(temp-25) {convection} line to ( dni/2, -Lni/4)
natural(solid)=0 line to ( dni/2, 3*Lni/4)
natural(solid)=0 natural(temp)=alfa*(temp-25) line to ( 0, 3*Lni/4)
natural(solid)=0 natural(temp)=0 line to close {no heat transport at axis of symmetry}
REGION 'titan'
ro=4430     c=0.0005*temp^2-0.0062*temp+584.93     lambda=spline table('titan_lambda.tbl')     res=spline table('titan_res.tbl')
Qm=295600     Tm=1632     T0=28     Tinit=25     sinit=1
start (dni/2, 0)
natural(solid)=0 natural(U)=0 natural(temp)=alfa*(temp-25) line to (Dti/2, 0)
natural(solid)=0 value(U)=-1.71e-6 * (Laram / Ati) * I/2 + 1e-10 natural(temp)=0 line to (Dti/2, 1.25*mm)
natural(solid)=0 natural(U)=0 natural(temp)=alfa*(temp-25) line to (Dti/2, Lti-1.25*mm)
natural(solid)=0 value(U)=1.71e-6 * (Laram / Ati) * I/2 + 1e-10 natural(temp)=0 line to (Dti/2, Lti) bevel(0.5*mm)
natural(solid)=0 natural(U)=0 natural(temp)=alfa*(temp-25) line to (dni/2, Lti)
natural(solid)=0 natural(U)=0 line to close
REGION 'rez_#1'
ro=8960     c=385     lambda=401     res=1.72e-8
Qm=176000     Tm=1085     T0=50 ! 1
Tinit=25     sinit=1
start (Dti/2, Lti-1.25*mm)
natural(U)=0 natural(temp)=alfa*(temp-25) line to (Dti/2+3.5*mm, Lti-1.25*mm)
natural(U)=0 natural(temp)=alfa*(temp-25) line to (Dti/2+3.5*mm, Lti+28.75*mm)
natural(U)=0 line to (Dti/2, Lti+28.75*mm)
natural(U)=0 line to close
REGION 'rez_#2'
ro=8960     c=385     lambda=401     res=1.72e-8
Qm=176000     Tm=1085     T0=50 ! 1
Tinit=25     sinit=1
start (Dti/2, 1.25*mm)
natural(U)=0 natural(temp)=alfa*(temp-25) line to (Dti/2+8*mm, 1.25*mm)
natural(U)=0 natural(temp)=alfa*(temp-25) line to (Dti/2+8*mm, -14.75*mm)
natural(U)=0 natural(temp)=alfa*(temp-25) line to (Dti/2, -14.75*mm)
natural(U)=0 line to close

time from 0 to 10

monitors
  for t=t_elo,t_elo+t_heg


PLOTS
for t=0 by 0.01 to 1 by 1 to 10
contour(temp) painted zoom(0, -Lni/4, 15*mm, 15*mm) range(0, 1600)
contour(solid) painted zoom(0, -Lni/4, 15*mm, 15*mm) range(0, 1)
vector(flux) zoom(0, -Lni/4, 15*mm, 15*mm)
elevation(temp) from (dni/4, -Lni/4) to (dni/4, 3*Lni/4)
elevation(temp) from (dni/4+Dti/4, 0) to (dni/4+Dti/4, Lti)
vector(J) zoom(0, -Lni/4, 15*mm, 15*mm)
history(temp) at (dni/2-0.1*mm, Lti/2)  at (dni/2-0.3*mm, Lti/2) at (dni/2-0.6*mm, Lti/2)
history(temp) at  (dni/2+0.1*mm, Lti/2) at (dni/4+0.05*mm+Dti/4, Lti/2) at (Dti/2, Lti/2)
history(integral(ro*c*(temp-20)))
history( 0.5*erfc(4*(temp-Tm)/T0) , solid ) at (dni/2-0.01*mm, Lti/2)
History(I)

END


